@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_CONTAINERHANDLE_SHARED_H
 #define _GLIBMM_CONTAINERHANDLE_SHARED_H
 
-/* $Id: containerhandle_shared.h,v 1.12 2006/09/19 20:36:42 murrayc Exp $ */
+/* $Id: containerhandle_shared.h,v 1.8.2.1 2005/01/21 20:12:50 murrayc Exp $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -314,36 +314,6 @@ struct TypeTraits<std::string>
     { g_free(const_cast<CTypeNonConst>(str)); }
 };
 
-/** Specialization for bool
- * @ingroup ContHelpers
- */
-template <>
-struct TypeTraits<bool>
-{
-  typedef bool          CppType;
-  typedef gboolean*     CType;
-  typedef gboolean*     CTypeNonConst;
-
-  static CType to_c_type (CppType val) { return (int*)GINT_TO_POINTER(val); }
-  static CType to_c_type (CType ptr)   { return ptr;                        }  
-
-  static CppType to_cpp_type(CType ptr)
-  { 
-    if(ptr)
-    {
-	  //We use this for gboolean too, because it is actually an int.
-	  return GPOINTER_TO_INT(ptr);
-	}
-	else
-	  return CppType();
-  }
-
-  static void release_c_type(CType /* ptr */)
-  {
-
-  }
-};
-
 #endif /* DOXYGEN_SHOULD_SKIP_THIS */
 
 
